from __future__ import annotations

from datetime import datetime
from pydantic import BaseModel, Field


class HistoryRecord(BaseModel):
    release: str
    hash: str
    deployed: str
    released: str
    distros: list[str] | None = None

    @staticmethod
    def _parse_dt(s: str) -> datetime | None:
        return datetime.fromisoformat(s) if s else None

    @property
    def deployed_dt(self) -> datetime | None:
        return self._parse_dt(self.deployed)

    @property
    def released_dt(self) -> datetime | None:
        return self._parse_dt(self.released)


class UpdatesInfo(BaseModel):
    releases: list[HistoryRecord] = Field(default_factory=list)
    blocked: list[str] = Field(default_factory=list)
    available_products: list[str] = Field(default_factory=list)
    error: str | None = None
